@@ -28,7 +28,7 @@ from ..tools import *
 from ..classify_rascore import classify_rascore
 
 
-def app():
+def classify_page():
 
     entry_table_path = get_file_path(
         entry_table_file,
